@@ -29,6 +29,10 @@
 
 #ifdef HAVE_GIO
 #include <gio/gio.h>
+#else
+  #ifdef HAVE_GNOMEVFS
+  #include <libgnomevfs/gnome-vfs-mime.h>
+  #endif
 #endif
 
 /* Use the RSA reference implementation included in the RFC-1321, http://www.freesoft.org/CIE/RFC/1321/ */
@@ -593,7 +597,19 @@ update_file_mime (FileRow *row, const gchar *complete_filename)
 		value = gda_value_new_null ();
 	g_object_unref (file);
 #else
+  #ifdef HAVE_GNOMEVFS
+	const gchar *mime;
+	
+	mime = gnome_vfs_get_file_mime_type (complete_filename, NULL, FALSE);
+	if (mime) {
+		value = gda_value_new (G_TYPE_STRING);
+		g_value_set_string (value, mime);
+	}
+	else 
+		value = gda_value_new_null ();
+  #else
 	value = gda_value_new_null ();
+  #endif
 #endif
 
 	if (value) {
@@ -1034,11 +1050,7 @@ gda_data_model_dir_set_values (GdaDataModel *model, gint row, GList *values, GEr
 											   new_filename);
 						}
 					}
-#if GLIB_CHECK_VERSION(2,22,0)
-					g_mapped_file_unref (old_file);
-#else
 					g_mapped_file_free (old_file);
-#endif
 				}
 				if (!allok) {
 					gchar *str;
@@ -1053,7 +1065,7 @@ gda_data_model_dir_set_values (GdaDataModel *model, gint row, GList *values, GEr
 					return FALSE;
 				}
 				else {
-					/* renaming succeeded => update FileRow */
+					/* renaming succedded => update FileRow */
 #ifndef G_OS_WIN32
 					g_rmdir (old_path);
 #endif
@@ -1095,7 +1107,7 @@ gda_data_model_dir_set_values (GdaDataModel *model, gint row, GList *values, GEr
 				return FALSE;
 			}
 			else {
-				/* renaming succeeded => update FileRow */
+				/* renaming succedded => update FileRow */
 				gda_value_free (frow->filename_value);
 				frow->filename_value = gda_value_copy (value);
 				if (frow->raw_filename_value) {
