@@ -89,9 +89,6 @@ typedef struct _GdaStatement GdaStatement;
 typedef struct _GdaStatementClass GdaStatementClass;
 typedef struct _GdaStatementPrivate GdaStatementPrivate;
 
-typedef struct _GdaRepetitiveStatement GdaRepetitiveStatement;
-typedef struct _GdaRepetitiveStatementClass GdaRepetitiveStatementClass;
-
 typedef struct _GdaSqlParser GdaSqlParser;
 typedef struct _GdaSqlParserClass GdaSqlParserClass;
 typedef struct _GdaSqlParserPrivate GdaSqlParserPrivate;
@@ -109,19 +106,9 @@ typedef struct _GdaMetaStructClass   GdaMetaStructClass;
 typedef struct _GdaMetaStructPrivate GdaMetaStructPrivate;
 
 /*
- * GdaTree
+ * Determines if @word is a reserved SQL keyword
  */
-typedef struct _GdaTree GdaTree;
-typedef struct _GdaTreeClass GdaTreeClass;
-typedef struct _GdaTreePrivate GdaTreePrivate;
-
-typedef struct _GdaTreeManager GdaTreeManager;
-typedef struct _GdaTreeManagerClass GdaTreeManagerClass;
-typedef struct _GdaTreeManagerPrivate GdaTreeManagerPrivate;
-
-typedef struct _GdaTreeNode GdaTreeNode;
-typedef struct _GdaTreeNodeClass GdaTreeNodeClass;
-typedef struct _GdaTreeNodePrivate GdaTreeNodePrivate;
+typedef gboolean (*GdaSqlReservedKeywordsFunc) (const gchar *word);
 
 /*
  * Win32 adaptations
