@@ -1,5 +1,5 @@
 /* GDA Library
- * Copyright (C) 2008 The GNOME Foundation.
+ * Copyright (C) 2008 - 2010 The GNOME Foundation.
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -40,7 +40,7 @@ GQuark gda_easy_error_quark (void)
 }
 
 /**
- * gda_prepare_create_database
+ * gda_prepare_create_database:
  * @provider: the database provider to use
  * @db_name: the name of the database to create, or %NULL
  * @error: a place to store errors, or %NULL
@@ -79,7 +79,7 @@ gda_prepare_create_database (const gchar *provider, const gchar *db_name, GError
 }
 
 /**
- * gda_perform_create_database
+ * gda_perform_create_database:
  * @provider: the database provider to use, or %NULL if @op has been created using gda_prepare_create_database()
  * @op: a #GdaServerOperation object obtained using gda_prepare_create_database()
  * @error: a place to store en error, or %NULL
@@ -109,7 +109,7 @@ gda_perform_create_database (const gchar *provider, GdaServerOperation *op, GErr
 }
 
 /**
- * gda_prepare_drop_database
+ * gda_prepare_drop_database:
  * @provider: the database provider to use
  * @db_name: the name of the database to drop, or %NULL
  * @error: a place to store errors, or %NULL
@@ -148,7 +148,7 @@ gda_prepare_drop_database (const gchar *provider, const gchar *db_name, GError *
 }
 
 /**
- * gda_perform_drop_database
+ * gda_perform_drop_database:
  * @provider: the database provider to use, or %NULL if @op has been created using gda_prepare_drop_database()
  * @op: a #GdaServerOperation object obtained using gda_prepare_drop_database()
  * @error: a place to store en error, or %NULL
@@ -178,14 +178,14 @@ gda_perform_drop_database (const gchar *provider, GdaServerOperation *op, GError
 }
 
 /**
- * gda_execute_select_command
+ * gda_execute_select_command:
  * @cnc: an opened connection
- * @sql: a query statement must begin with "SELECT"
+ * @sql: a query statament must begin with "SELECT"
  * @error: a place to store errors, or %NULL
  * 
  * Execute a SQL SELECT command over an opened connection.
  *
- * Returns: a new #GdaDataModel if successful, NULL otherwise
+ * Returns: a new #GdaDataModel if succesfull, NULL otherwise
  */
 GdaDataModel *          
 gda_execute_select_command (GdaConnection *cnc, const gchar *sql, GError **error)
@@ -214,9 +214,9 @@ gda_execute_select_command (GdaConnection *cnc, const gchar *sql, GError **error
 }
 
 /**
- * gda_execute_sql_command
+ * gda_execute_sql_command:
  * @cnc: an opened connection
- * @sql: a query statement must begin with "SELECT"
+ * @sql: a query statament must begin with "SELECT"
  * @error: a place to store errors, or %NULL
  *
  * This is a convenience function to execute a SQL command over the opened connection.
@@ -248,10 +248,9 @@ gda_execute_non_select_command (GdaConnection *cnc, const gchar *sql, GError **e
 }
 
 /**
- * gda_prepare_create_table
+ * gda_prepare_create_table:
  * @cnc: an opened connection
- * @table_name:
- * @num_columns
+ * @table_name: name of the table to create
  * @error: a place to store errors, or %NULL
  * @...: group of three arguments for column's name, column's #GType 
  * and a #GdaEasyCreateTableFlag flag, finished with NULL
@@ -308,7 +307,12 @@ gda_prepare_create_table (GdaConnection *cnc, const gchar *table_name, GError **
 
 		op = gda_server_provider_create_operation (server, cnc, 
 							   GDA_SERVER_OPERATION_CREATE_TABLE, NULL, error);
-		gda_server_operation_set_value_at (op, table_name, error, "/TABLE_DEF_P/TABLE_NAME");
+		if (!GDA_IS_SERVER_OPERATION(op))
+			return NULL;
+		if(!gda_server_operation_set_value_at (op, table_name, error, "/TABLE_DEF_P/TABLE_NAME")) {
+			g_object_unref (op);
+			return NULL;
+		}
 				
 		va_start (args, error);
 		type = 0;
@@ -318,7 +322,10 @@ gda_prepare_create_table (GdaConnection *cnc, const gchar *table_name, GError **
 		
 		while ((arg = va_arg (args, gchar*))) {
 			/* First argument for Column's name */			
-			gda_server_operation_set_value_at (op, arg, error, "/FIELDS_A/@COLUMN_NAME/%d", i);
+			if(!gda_server_operation_set_value_at (op, arg, error, "/FIELDS_A/@COLUMN_NAME/%d", i)){
+				g_object_unref (op);
+				return NULL;
+			}
 		
 			/* Second to Define column's type */
 			type = va_arg (args, GType);
@@ -330,16 +337,33 @@ gda_prepare_create_table (GdaConnection *cnc, const gchar *table_name, GError **
 			}
 			dbms_type = (gchar *) gda_server_provider_get_default_dbms_type (server, 
 											 cnc, type);
-			gda_server_operation_set_value_at (op, dbms_type, error, "/FIELDS_A/@COLUMN_TYPE/%d", i);
+			if (!gda_server_operation_set_value_at (op, dbms_type, error, "/FIELDS_A/@COLUMN_TYPE/%d", i)){
+				g_object_unref (op);
+				return NULL;
+			}
 		
 			/* Third for column's flags */
 			flag = va_arg (args, GdaEasyCreateTableFlag);
 			if (flag & GDA_EASY_CREATE_TABLE_PKEY_FLAG)
-				gda_server_operation_set_value_at (op, "TRUE", error, "/FIELDS_A/@COLUMN_PKEY/%d", i);
+				if(!gda_server_operation_set_value_at (op, "TRUE", error, "/FIELDS_A/@COLUMN_PKEY/%d", i)){
+					g_object_unref (op);
+					return NULL;
+				}
 			if (flag & GDA_EASY_CREATE_TABLE_NOT_NULL_FLAG)
-				gda_server_operation_set_value_at (op, "TRUE", error, "/FIELDS_A/@COLUMN_NNUL/%d", i);
+				if(!gda_server_operation_set_value_at (op, "TRUE", error, "/FIELDS_A/@COLUMN_NNUL/%d", i)){
+					g_object_unref (op);
+					return NULL;
+				}
 			if (flag & GDA_EASY_CREATE_TABLE_AUTOINC_FLAG)
-				gda_server_operation_set_value_at (op, "TRUE", error, "/FIELDS_A/@COLUMN_AUTOINC/%d", i);
+				if (!gda_server_operation_set_value_at (op, "TRUE", error, "/FIELDS_A/@COLUMN_AUTOINC/%d", i)){
+					g_object_unref (op);
+					return NULL;
+				}
+			if (flag & GDA_EASY_CREATE_TABLE_UNIQUE_FLAG)
+				if(!gda_server_operation_set_value_at (op, "TRUE", error, "/FIELDS_A/@COLUMN_UNIQUE/%d", i)){
+					g_object_unref (op);
+					return NULL;
+				}
 			if (flag & GDA_EASY_CREATE_TABLE_FKEY_FLAG) {
 				gint j;
 				gint fields;
@@ -350,8 +374,11 @@ gda_prepare_create_table (GdaConnection *cnc, const gchar *table_name, GError **
 				refs++;
 				
 				fkey_table = va_arg (args, gchar*);				
-				gda_server_operation_set_value_at (op, fkey_table, error, 
-								   "/FKEY_S/%d/FKEY_REF_TABLE", refs);
+				if (!gda_server_operation_set_value_at (op, fkey_table, error, 
+								   "/FKEY_S/%d/FKEY_REF_TABLE", refs)){
+					g_object_unref (op);
+					return NULL;
+				}
 				
 				fields = va_arg (args, gint);
 				
@@ -359,21 +386,33 @@ gda_prepare_create_table (GdaConnection *cnc, const gchar *table_name, GError **
 					gchar *field, *rfield;
 					
 					field = va_arg (args, gchar*);				
-					gda_server_operation_set_value_at (op, field, error, 
-									   "/FKEY_S/%d/FKEY_FIELDS_A/@FK_FIELD/%d", refs, j);
+					if(!gda_server_operation_set_value_at (op, field, error, 
+									   "/FKEY_S/%d/FKEY_FIELDS_A/@FK_FIELD/%d", refs, j)){
+						g_object_unref (op);
+						return NULL;
+					}
 					
 					rfield = va_arg (args, gchar*);
-					gda_server_operation_set_value_at (op, rfield, error, 
-									   "/FKEY_S/%d/FKEY_FIELDS_A/@FK_REF_PK_FIELD/%d", refs, j);
+					if(!gda_server_operation_set_value_at (op, rfield, error, 
+									   "/FKEY_S/%d/FKEY_FIELDS_A/@FK_REF_PK_FIELD/%d", refs, j)){
+						g_object_unref (op);
+						return NULL;
+					}
 					
 				}
 				
 				fkey_ondelete = va_arg (args, gchar*);
-				gda_server_operation_set_value_at (op, fkey_ondelete, error, 
-								   "/FKEY_S/%d/FKEY_ONDELETE", refs);
+				if (!gda_server_operation_set_value_at (op, fkey_ondelete, error, 
+								   "/FKEY_S/%d/FKEY_ONDELETE", refs)){
+					g_object_unref (op);
+					return NULL;
+				}
 				fkey_onupdate = va_arg (args, gchar*);
-				gda_server_operation_set_value_at (op, fkey_onupdate, error, 
-								   "/FKEY_S/%d/FKEY_ONUPDATE", refs);
+				if(!gda_server_operation_set_value_at (op, fkey_onupdate, error, 
+								   "/FKEY_S/%d/FKEY_ONUPDATE", refs)){
+					g_object_unref (op);
+					return NULL;
+				}
 			}
 			
 			i++;
@@ -393,7 +432,7 @@ gda_prepare_create_table (GdaConnection *cnc, const gchar *table_name, GError **
 }
 
 /**
- * gda_perform_create_table
+ * gda_perform_create_table:
  * @op: a valid #GdaServerOperation
  * @error: a place to store errors, or %NULL
  * 
@@ -422,7 +461,7 @@ gda_perform_create_table (GdaServerOperation *op, GError **error)
 }
 
 /**
- * gda_prepare_drop_table
+ * gda_prepare_drop_table:
  * @cnc: an opened connection
  * @table_name: name of the table to drop
  * @error: a place to store errors, or %NULL
@@ -461,7 +500,7 @@ gda_prepare_drop_table (GdaConnection *cnc, const gchar *table_name, GError **er
 }
 
 /**
- * gda_perform_drop_table
+ * gda_perform_drop_table:
  * @op: a #GdaServerOperation object
  * @error: a place to store errors, or %NULL
  * 
@@ -500,16 +539,16 @@ gtype_equal (gconstpointer a, gconstpointer b)
 }
 
 /**
- * gda_get_default_handler
+ * gda_get_default_handler:
  * @for_type: a #GType type
  * 
  * Obtain a pointer to a #GdaDataHandler which can manage #GValue values of type @for_type. The returned
  * data handler will be adapted to use the current locale information (for example dates will be formatted
- * taking into account the locale).
+ * taking into accoutn the locale).
  *
  * The returned pointer is %NULL if there is no default data handler available for the @for_type data type
  *
- * Returns: a #GdaDataHandler which must not be modified or destroyed.
+ * Returns: (transfer none): a #GdaDataHandler which must not be modified or destroyed.
  */
 GdaDataHandler *
 gda_get_default_handler (GType for_type)
@@ -552,7 +591,7 @@ gda_get_default_handler (GType for_type)
 }
 
 /**
- * gda_insert_row_into_table
+ * gda_insert_row_into_table:
  * @cnc: an opened connection
  * @table: table's name to insert into
  * @error: a place to store errors, or %NULL
@@ -604,11 +643,11 @@ gda_insert_row_into_table (GdaConnection *cnc, const gchar *table, GError **erro
 }
 
 /**
- * gda_insert_row_into_table_v
+ * gda_insert_row_into_table_v:
  * @cnc: an opened connection
  * @table: table's name to insert into
- * @col_names: a list of column names (as const gchar *)
- * @values: a list of values (as #GValue)
+ * @col_names: (element-type utf8): a list of column names (as const gchar *)
+ * @values: (element-type GValue): a list of values (as #GValue)
  * @error: a place to store errors, or %NULL
  *
  * @col_names and @values must have length (&gt;= 1).
@@ -714,7 +753,7 @@ gda_insert_row_into_table_v (GdaConnection *cnc, const gchar *table,
 
 
 /**
- * gda_update_row_in_table
+ * gda_update_row_in_table:
  * @cnc: an opened connection
  * @table: the table's name with the row's values to be updated
  * @condition_column_name: the name of the column to used in the WHERE condition clause
@@ -770,13 +809,13 @@ gda_update_row_in_table (GdaConnection *cnc, const gchar *table,
 }
 
 /**
- * gda_update_row_in_table_v
+ * gda_update_row_in_table_v:
  * @cnc: an opened connection
  * @table: the table's name with the row's values to be updated
  * @condition_column_name: the name of the column to used in the WHERE condition clause
  * @condition_value: the @condition_column_type's GType
- * @col_names: a list of column names (as const gchar *)
- * @values: a list of values (as #GValue)
+ * @col_names: (element-type utf8): a list of column names (as const gchar *)
+ * @values: (element-type GValue): a list of values (as #GValue)
  * @error: a place to store errors, or %NULL
  *
  * @col_names and @values must have length (&gt;= 1).
@@ -918,7 +957,7 @@ gda_update_row_in_table_v (GdaConnection *cnc, const gchar *table,
 }
 
 /**
- * gda_delete_row_from_table
+ * gda_delete_row_from_table:
  * @cnc: an opened connection
  * @table: the table's name with the row's values to be updated
  * @condition_column_name: the name of the column to used in the WHERE condition clause
