@@ -932,6 +932,7 @@ load_xml_spec (GdaServerOperation *op, xmlNodePtr specnode, const gchar *root, G
 		}
 		else {
 			node = node->next;
+			g_free (path_name);
 			continue;
 		}
 		
@@ -1210,14 +1211,10 @@ gda_server_operation_op_type_to_string (GdaServerOperationType type)
 		return "DROP_INDEX";
         case GDA_SERVER_OPERATION_RENAME_TABLE:
 		return "RENAME_TABLE";
-        case GDA_SERVER_OPERATION_COMMENT_TABLE:
-		return "COMMENT_TABLE";
         case GDA_SERVER_OPERATION_ADD_COLUMN:
 		return "ADD_COLUMN";
         case GDA_SERVER_OPERATION_DROP_COLUMN:
 		return "DROP_COLUMN";
-        case GDA_SERVER_OPERATION_COMMENT_COLUMN:
-		return "COMMENT_COLUMN";
 	case GDA_SERVER_OPERATION_CREATE_VIEW:
 		return "CREATE_VIEW";
 	case GDA_SERVER_OPERATION_DROP_VIEW:
@@ -2235,7 +2232,7 @@ gda_server_operation_set_value_at (GdaServerOperation *op, const gchar *value, G
  * Tells if all the required values in @op have been defined.
  *
  * if @xml_file is not %NULL, the validity of @op is tested against that specification, 
- * and not against the current @op's specification.
+ * and not againts the current @op's specification.
  *
  * Returns: TRUE if @op is valid
  */
