@@ -1,5 +1,5 @@
 /* GDA SQLite provider
- * Copyright (C) 1998 - 2008 The GNOME Foundation.
+ * Copyright (C) 1998 - 2009 The GNOME Foundation.
  *
  * AUTHORS:
  *	Rodrigo Moya <rodrigo@gnome-db.org>
@@ -41,17 +41,10 @@
  * Provider's specific connection data
  */
 typedef struct {
+	GdaConnection *gdacnc;
 	sqlite3      *connection;
 	gchar        *file;
 	GHashTable   *types; /* key = type name, value = GType */
-	GdaDataModel *functions_model;
-	GdaDataModel *aggregates_model;
 } SqliteConnectionData;
 
-/* 
- * Utility functions
- */
-void  _gda_sqlite_compute_types_hash (SqliteConnectionData *scnc);
-GType _gda_sqlite_compute_g_type (int sqlite_type);
-
 #endif
