@@ -45,6 +45,27 @@ gda_postgres_sqlsate_to_gda_code (const gchar *sqlstate)
         }
 }
 
+/*
+ * Returns: @str
+ */
+static gchar *
+utf8_validate (gchar *str)
+{
+	gchar *tmp;
+	if (g_utf8_validate (str, -1, (const gchar **) &tmp))
+		return str;
+	else {
+		*tmp = ' ';
+		for (tmp++; tmp; tmp++) {
+			if (g_utf8_validate (tmp, -1, (const gchar **) &tmp))
+				return str;
+			else
+				*tmp = ' ';
+		}
+		return tmp;
+	}
+}
+
 /*
  * Create a new #GdaConnectionEvent object and "adds" it to @cnc
  *
@@ -73,7 +94,7 @@ _gda_postgres_make_error (GdaConnection *cnc, PGconn *pconn, PGresult *pg_res, G
                         message = g_strdup (PQerrorMessage (pconn));
                         gda_code = GDA_CONNECTION_EVENT_CODE_UNKNOWN;
                 }
-
+		utf8_validate (message);
 		
 		gchar *ptr = message;
 		if (g_str_has_prefix (message, "ERROR:"))
@@ -107,11 +128,7 @@ _gda_postgres_make_error (GdaConnection *cnc, PGconn *pconn, PGresult *pg_res, G
         return error_ev;
 }
 
-/* 
- * Returns NULL if an error occurred
- *
- * WARNING: it does not check that @pconn can safely be used
- */
+/* to be used only while initializing a connection */
 PGresult *
 _gda_postgres_PQexec_wrap (GdaConnection *cnc, PGconn *pconn, const char *query)
 {
