@@ -53,12 +53,12 @@ gda_internal_command_arg_remove_quotes (gchar *str)
 
         total = strlen (str);
         if (str[total-1] == delim) {
-                /* string is correctly terminated by a double quote */
+                /* string is correclty terminated by a double quote */
                 g_memmove (str, str+1, total-2);
                 total -=2;
         }
         else {
-                /* string is _not_ correctly terminated by a double quote */
+                /* string is _not_ correclty terminated by a double quote */
                 g_memmove (str, str+1, total-1);
                 total -=1;
         }
@@ -346,21 +346,7 @@ gda_internal_command_dict_sync (SqlConsole *console, GdaConnection *cnc, const g
 	res = g_new0 (GdaInternalCommandResult, 1);
 	res->type = GDA_INTERNAL_COMMAND_RESULT_EMPTY;
 
-	if (args[0] && *args[0]) {
-		GdaMetaContext context;
-		memset (&context, 0, sizeof (context));
-		if (*args[0] == '_')
-			context.table_name = (gchar*) args[0];
-		else
-			context.table_name = g_strdup_printf ("_%s", args[0]);
-		if (!gda_connection_update_meta_store (cnc, &context, error)) {
-			g_free (res);
-			res = NULL;
-		}
-		if (*args[0] != '_')
-			g_free (context.table_name);
-	}
-	else if (!gda_connection_update_meta_store (cnc, NULL, error)) {
+	if (!gda_connection_update_meta_store (cnc, NULL, error)) {
 		g_free (res);
 		res = NULL;
 	}
@@ -853,7 +839,7 @@ gda_internal_command_detail (SqlConsole *console, GdaConnection *cnc, const gcha
 					g_string_append_printf (string, " '%s'", g_value_get_string (cvalue));
 
 					str = "SELECT ref_table_schema, ref_table_name, fk_column, ref_column "
-						"FROM _detailed_fk WHERE fk_table_catalog = ##tc::string "
+						"FROM _detailled_fk WHERE fk_table_catalog = ##tc::string "
 						"AND fk_table_schema = ##ts::string AND fk_table_name = ##tname::string AND "
 						"fk_constraint_name = ##cname::string "
 						"ORDER BY ordinal_position";
